#ifndef GOOSNES_READCONF_H
#	define GOOSNES_READCONF_H

#ifdef HAVE_CONFIG_H
#	include "config.h"
#endif

#if STDC_HEADERS
#	include <stdio.h>
#	include <stdlib.h>
#	include <string.h>
#	include <assert.h>
#endif

#if HAVE_SYS_STAT_H
#	include <sys/stat.h>
#endif

#if HAVE_SYS_TYPES_H
#	include <sys/types.h>
#endif

#if HAVE_LIBXML2
#	include <libxml/xmlmemory.h>
#	include <libxml/parser.h>
#	include <libxml/tree.h>
#endif

#include <gtk/gtk.h>
#include "support.h"

#include "writeconf.h"

#define ARGLENGTH 128

/* desc: wrapper around readxmlconf in case
 * GooSNES begins accepting different conf file
 * formats
 *
 * pre: button is a widget in the main GooSNES window,
 * conffile is the conf file to be used
 * if conffile is NULL, GooSNES will look
 * in ${HOME}/.goosnes/goosnes.conf, then
 * in /etc/goosnes.conf
 *
 * post: returns nonzero on success, zero on failure
 */
int	readconf(GtkWidget *button,char *conffile);

/* desc: Reads in a GooSNES conf file
 *
 * pre: button is a widget in the main GooSNES window,
 * buf is the conf file to be used
 * if buf is NULL, GooSNES will look
 * in ${HOME}/.goosnes/goosnes.conf, then
 * in /etc/goosnes.conf
 *
 * post: returns nonzero on success, zero on failure
 *
 * usage: use readconf instead
 */
int	readxmlconf(GtkWidget *button,char *buf);

/* desc: parses the rom section of a GooSNES conf file
 *
 * pre: button is a widget in the main GooSNES window,
 * doc is a pointer to the parsed conf document,
 * curr is a pointer to the rom section node
 *
 * post: returns nonzero on success, zero on failure
 */
int	parserom(GtkWidget *button,xmlDocPtr doc,xmlNodePtr curr);

/* desc: parses the screen section of a GooSNES conf file
 *
 * pre: button is a widget in the main GooSNES window,
 * doc is a pointer to the parsed conf document,
 * curr is a pointer to the screen section node
 *
 * post: returns nonzero on success, zero on failure
 */
int	parsescreen(GtkWidget *button,xmlDocPtr doc,xmlNodePtr curr);

/* desc: parses the sound section of a GooSNES conf file
 *
 * pre: button is a widget in the main GooSNES window,
 * doc is a pointer to the parsed conf document,
 * curr is a pointer to the sound section node
 *
 * post: returns nonzero on success, zero on failure
 */
int	parsesound(GtkWidget *button,xmlDocPtr doc,xmlNodePtr curr);

/* desc: parses the joystick section of a GooSNES conf file
 *
 * pre: button is a widget in the main GooSNES window,
 * doc is a pointer to the parsed conf document,
 * curr is a pointer to the joystick section node
 *
 * post: returns nonzero on success, zero on failure
 */
int parsejoystick(GtkWidget *button,xmlDocPtr doc,xmlNodePtr curr);


#endif /* GOOSNES_READCONF_H */
