#ifndef GOOSNES_WRITECONF_H
#	define GOOSNES_WRITECONF_H

#ifdef HAVE_CONFIG_H
#	include "config.h"
#endif

#if STDC_HEADERS
#	include <stdio.h>
#	include <stdlib.h>
#	include <string.h>
#	include <assert.h>
#endif

#if HAVE_SYS_STAT_H
#	include <sys/stat.h>
#endif

#if HAVE_SYS_TYPES_H
#	include <sys/types.h>
#endif

#if HAVE_LIBXML2
#	include <libxml/tree.h>
#endif

#include "support.h"

#define COMPRESSION	9

/* desc: wrapper around writexmlconf
 *
 * pre: button is a widget in the GooSNES main window,
 * conffilename is the name of the conf file to be written
 * if conffilename is NULL, GooSNES will attempt to write
 * ${HOME}/.goosnes/goosnes.conf, then /etc/goosnes.conf
 *
 * post: nonzero is returned on success, zero on failure
 */
int	writeconf(const GtkWidget *button, char *conffilename);

/* desc: writes a GooSNES conf file
 *
 * pre: each of the strings represents a conf file value
 * for a snes9x setting, except conffilename, which is
 * the name of the conf file to be written
 * if conffilename is NULL, GooSNES will attempt to write
 * ${HOME}/.goosnes/goosnes.conf, then /etc/goosnes.conf
 *
 * post: nonzero is returned on success, zero on failure
 * conffilename will contain the default name if it
 * was originally NULL
 */
int	writexmlconf(	const char *romfile,		/* rom section */
				const char *snapshotfile,
				const char *hdma,
				const char *loadsnapshot,
				const char *windoweffects,
				const char *speedhacks,
				const char *forcehi,
				const char *forcelo,
				const char *interleaved,
				const char *interleaved2,
				const char *swaplayering,
				const char *cycles,			/* screen section */
				const char *snes9x,
				const char *forcentsc,
				const char *forcepal,
				const char *doublescreensize,
				const char *buffersize,	/* sound section */
				const char *usesound,
				const char *stereo,
				const char *usejoystick,	/* joystick section */
				const char *oldjoystick,
				const char *swapjoypads,
				const char *joy1dev,
				const char *joy2dev,
				const char *a,
				const char *b,
				const char *x,
				const char *y,
				const char *l,
				const char *r,
				const char *start,
				const char *select,
				char *conffilename);

/* desc: generates a default conf file name
 * ${HOME}/.goosnes/goosnes.conf if possible
 * else /etc/goosnes.conf
 *
 * pre: buf is a preallocated array of const characters
 *
 * post: the default filename is returned,
 * and its value remains in buf
 */
const char*	get_conffilename(char *buf);

#endif
